@@ -21,9 +21,12 @@ void orc_c64x_init (void);
 void orc_c64x_c_init (void);
 void orc_mips_init (void);
 
+typedef struct _OrcCodeRegion OrcCodeRegion;
 typedef struct _OrcCodeChunk OrcCodeChunk;
 
-/* This is internal API, nothing in the public headers returns an OrcCodeChunk */
+/* This is internal API, nothing in the public headers returns an OrcCodeChunk
+ */
+OrcCodeRegion * orc_code_region_alloc (void);
 void orc_code_chunk_free (OrcCodeChunk *chunk);
 
 extern int _orc_data_cache_size_level1;
@@ -38,6 +41,8 @@ void orc_compiler_emit_invariants (OrcCompiler *compiler);
 int orc_program_has_float (OrcCompiler *compiler);
 
 char* _orc_getenv (const char *var);
+void orc_opcode_sys_init (void);
+
 #endif
 
 ORC_END_DECLS
