@@ -362,7 +362,7 @@ orc_parse_splat_error (OrcParseError **errors, int n_errors, char **log)
     int n = sizeof ("error: 123456789012345    \n") + strlen (errors[i]->source) + strlen (errors[i]->text);
     if (len + n >= size) {
       size += MAX (n, 256);
-      _log = realloc(_log, size);
+      _log = orc_realloc(_log, size);
     }
     len += sprintf (_log + len, "%s @ %i: error: %s\n", errors[i]->source, errors[i]->line_number, errors[i]->text);
   }
@@ -430,7 +430,8 @@ orc_parse_add_error_valist (OrcParser *parser, const char *format, va_list args)
 
 #ifdef HAVE_VASPRINTF
   char *text = NULL;
-  vasprintf (&text, format, args);
+  if (vasprintf (&text, format, args) < 0)
+    ORC_ASSERT (0);
 #elif defined(_UCRT)
   char text[ORC_ERROR_LENGTH] = { '\0' };
   vsnprintf_s (text, ORC_ERROR_LENGTH, _TRUNCATE, format, args);
